===
API
===

.. autofunction:: demes.loads
.. autofunction:: demes.load
.. autofunction:: demes.dumps
.. autofunction:: demes.dump

.. autoclass:: demes.Epoch
    :members:

.. autoclass:: demes.Migration
    :members:

.. autoclass:: demes.Pulse
    :members:

.. autoclass:: demes.Deme
    :members:

.. autoclass:: demes.DemeGraph
    :members:
